@@ -1,6 +1,6 @@
 # Module: appTrial.py
 # Holds data structures
-
+#__requires__= 'xlrd==1.2.0'
 
 import sys
 from sys import platform as _platform
@@ -14,8 +14,10 @@ import tkinter
 from operator import add
 from collections import defaultdict
 import pkg_resources
+#pkg_resources.require("xlrd==1.2.0")
 import pandas as pd
 
+#from xlrd import open_workbook
 if sys.version_info<(3,0,0):  # tkinter names for python 2
     print("Update to Python3 for best results... You may encounter errors")
     from Tkinter import *
@@ -136,7 +138,7 @@ class Parameters:
         self.focalMinDistance = focalMinDistance
         self.focalMaxDistance = focalMaxDistance
         self.semiFocalMinDistance = semiFocalMinDistance
-        self.semiFocalMaxDistance = semiFocalMinDistance
+        self.semiFocalMaxDistance = semiFocalMaxDistance
         self.corridoripeMaxVal = corridoripeMaxVal
         self.annulusCounterMaxVal = annulusCounterMaxVal
         self.quadrantTotalMaxVal = quadrantTotalMaxVal
@@ -330,13 +332,11 @@ def saveFileAsExperiment(software, filename, filedirectory):
 
             for row in range(1, headerLines):
                 if str(sheet.iloc[row, 0]).upper() == 'TRIAL NAME':
-                        aTrial.setname(sheet.iloc[row,1])
-                elif str(sheet.iloc[row, 0]).upper() == 'TRIAL ID':
-                    aTrial.settrial(int(sheet.iloc[row,1]))
+                    aTrial.setname(sheet.iloc[row,1])
                 elif str(sheet.iloc[row, 0]).upper() == 'ANIMAL ID':
                     aTrial.setanimal(sheet.iloc[row,1])
                 elif str(sheet.iloc[row, 0]).upper() == 'TRIAL':
-                    aTrial.settrial(int(sheet.iloc[row,1]))
+                    aTrial.settrial(sheet.iloc[row,1])
 
             for row in range(headerLines, number_of_rows):  # for each row
                 time = sheet.iloc[row,1]
@@ -392,7 +392,7 @@ def saveFileAsExperiment(software, filename, filedirectory):
 
             trialList.append(aTrial)
 
-        elif software == "watermaze":
+        elif software == "watermaze":  
             logging.info("Reading watermaze")
             experiment.setHasAnimalNames(True)
             experiment.setHasDateInfo(True)
